@@ -56,6 +56,11 @@ REPOSITORIES: Dict[str, Repository] = {
         commit="v1.2.0",
         cache_path="baxter_common",
     ),
+    "bhand_model": Repository(
+        url="https://github.com/jhu-lcsr-attic/bhand_model.git",
+        commit="937f4186d6458bd682a7dae825fb6f4efe56ec69",
+        cache_path="bhand_model",
+    ),
     "bullet3": Repository(
         url="https://github.com/bulletphysics/bullet3.git",
         commit="3.24",
@@ -96,6 +101,11 @@ REPOSITORIES: Dict[str, Repository] = {
         commit="v1.0.0",
         cache_path="gym-pybullet-drones",
     ),
+    "halodi-robot-models": Repository(
+        url="https://github.com/Halodi/halodi-robot-models.git",
+        commit="ba9e7c8cdbd63e20fc6526dbbea1b91c102fb820",
+        cache_path="halodi-robot-models",
+    ),
     "icub-models": Repository(
         url="https://github.com/robotology/icub-models.git",
         commit="v1.25.0",
@@ -118,9 +128,19 @@ REPOSITORIES: Dict[str, Repository] = {
     ),
     "mujoco_menagerie": Repository(
         url="https://github.com/deepmind/mujoco_menagerie.git",
-        commit="2665e9bc0f476e5f505ff929d758ed36f8618fa8",
+        commit="e946426aaaa56f59e14ad24ed2c22a3b1a04f124",
         cache_path="mujoco_menagerie",
     ),
+    "nao_robot": Repository(
+        url="https://github.com/ros-naoqi/nao_robot.git",
+        commit="67476469a1371b00b17538eb6ea336367ece7d44",
+        cache_path="nao_robot",
+    ),
+    "nasa-urdf-robots": Repository(
+        url="https://github.com/gkjohnson/nasa-urdf-robots.git",
+        commit="54cdeb1dbfb529b79ae3185a53e24fce26e1b74b",
+        cache_path="nasa-urdf-robots",
+    ),
     "pepper_description": Repository(
         url="https://github.com/jrl-umi3218/pepper_description.git",
         commit="cd9715bb5df7ad57445d953db7b1924255305944",
